@@ -1,7 +1,10 @@
 import numpy as np
 
+from pybsc.closest_indices import argclosest
 
-def get_timestamp_indices_wrt_base(base_timestamps, target_timestamps):
+
+def get_timestamp_indices_wrt_base(base_timestamps, target_timestamps,
+                                   style='after'):
     """Return timestamp indices with respect to base timestamps.
 
     Examples
@@ -11,9 +14,14 @@ def get_timestamp_indices_wrt_base(base_timestamps, target_timestamps):
     >>> get_timestamp_indices_wrt_base(base_timestamps, target_timestamps)
     array([0, 0, 1, 3])
     """
-    return np.maximum(
-        np.searchsorted(base_timestamps,
-                        target_timestamps, side="left") - 1, 0)
+    if style == 'after':
+        return np.maximum(
+            np.searchsorted(base_timestamps,
+                            target_timestamps, side="left") - 1, 0)
+    elif style == 'closest':
+        return argclosest(base_timestamps, target_timestamps)
+    else:
+        raise NotImplementedError
 
 
 def sorted_timestamps(timestamps):
